| Title: | Automatic Generation of Qualitative Color Palettes |
|---|---|
| Description: | Automatic generation of maximally distinct qualitative color palettes, optionally tailored to color deficiency. A set of colors or a subspace of a color space is used as input and a final palette of specified size is generated by picking colors that maximize the minimum pairwise difference among the chosen colors. Adaptations to color vision deficiency, background colors, and white points are supported. |
| Authors: | Johan Larsson [aut, cre] (ORCID: <https://orcid.org/0000-0002-4029-5945>) |
| Maintainer: | Johan Larsson <[email protected]> |
| License: | GPL-3 |
| Version: | 2.0.0.9000 |
| Built: | 2026-06-09 11:10:05 UTC |
| Source: | https://github.com/jolars/qualpalr |
Analyze a categorical color palette with respect to the differences between the colors in the palette.
analyze_palette( palette, cvd = c(protan = 0, deutan = 0, tritan = 0), bg = NULL, metric = c("ciede2000", "din99d", "cie76") )analyze_palette( palette, cvd = c(protan = 0, deutan = 0, tritan = 0), bg = NULL, metric = c("ciede2000", "din99d", "cie76") )
palette |
Either a matrix of RGB values (with values between 0 and 1), a data frame with RGB values, or a character vector of hex colors. |
cvd |
Color vision deficiency adaptation. This must be a named
vector with names |
bg |
Background color to consider (but not include) when
generating the palette. This is useful to avoid colors that are too
close to the background/canvas color. If |
metric |
The color metric to use for the color distance matrix. |
A list of lists, one for each type of color vision deficiency plus
normal vision. Each list contains difference_matrix, min_distances, and
bg_min_distance
pal <- qualpal(5) analyze_palette(pal$hex, cvd = c(protan = 1))pal <- qualpal(5) analyze_palette(pal$hex, cvd = c(protan = 1))
Convert colors between colorspaces
convert_colors(colors, from, to)convert_colors(colors, from, to)
colors |
A matrix of colors |
from |
The colorspace of the input colors, one of "rgb", "hsl", "din99d", "lab", "xyz" |
to |
The colorspace of the output colors, one of "rgb", "hsl", "lab", "xyz" |
The colors converted to the new colorspace
This function retrieves a color palette from the built-in palettes. To
see the available palettes, use list_palettes().
get_palette(palette = "ColorBrewer:Accent")get_palette(palette = "ColorBrewer:Accent")
palette |
A character string specifying the name of the color palette to |
A character vector of colors in hex format.
get_palette("Vermeer:LittleStreet")get_palette("Vermeer:LittleStreet")
List available color palettes
list_palettes()list_palettes()
A list of available color palettes. Each palette is a named list with a character vector.
list_palettes()list_palettes()
Plots the colors in an object of class "qualpal" as a scatterplot
matrix on either the DIN99d (the default) or HSL color space.
## S3 method for class 'qualpal' pairs(x, colorspace = c("DIN99d", "HSL", "RGB"), ...)## S3 method for class 'qualpal' pairs(x, colorspace = c("DIN99d", "HSL", "RGB"), ...)
x |
A list object of class |
colorspace |
The color space in which to plot the colors ("DIN99d", "HSL", or "RGB"). |
... |
Arguments to pass on to |
col_pal <- qualpal(3) pairs(col_pal) pairs(col_pal, colorspace = "HSL")col_pal <- qualpal(3) pairs(col_pal) pairs(col_pal, colorspace = "HSL")
Uses the colors in a qualpal object to compute and plot a
multidimensional scaling (MDS) map using cmdscale on the
Delta E DIN99d distance matrix.
## S3 method for class 'qualpal' plot(x, ...)## S3 method for class 'qualpal' plot(x, ...)
x |
An object of class |
... |
Arguments to pass on to |
col_pal <- qualpal(3) plot(col_pal)col_pal <- qualpal(3) plot(col_pal)
Print the result from a call to qualpal.
## S3 method for class 'qualpal' print(x, colorspace = c("HSL", "DIN99d", "RGB"), digits = 2, ...)## S3 method for class 'qualpal' print(x, colorspace = c("HSL", "DIN99d", "RGB"), digits = 2, ...)
x |
An object of class |
colorspace |
Color space to print colors in. |
digits |
Number of significant digits for the output.
(See print.default.) Setting it to |
... |
Arguments to pass to |
Prints the colors as a matrix in the specified color space as well as a distance matrix of the color differences. Invisibly returns x.
f <- qualpal(3) print(f, colorspace = "DIN99d", digits = 3)f <- qualpal(3) print(f, colorspace = "DIN99d", digits = 3)
Given a collection of colors, qualpal() algorithmically
tries to select to n most distinct colors from the provided
input colors, optionally taking color vision deficiency into account.
qualpal( n, colorspace = list(h = c(0, 360), s = c(0.2, 0.5), l = c(0.6, 0.85)), cvd = c(protan = 0, deutan = 0, tritan = 0), cvd_severity, bg = NULL, metric = c("ciede2000", "din99d", "cie76"), extend = NULL, white_point = c("D65", "D50", "D55", "A", "E") )qualpal( n, colorspace = list(h = c(0, 360), s = c(0.2, 0.5), l = c(0.6, 0.85)), cvd = c(protan = 0, deutan = 0, tritan = 0), cvd_severity, bg = NULL, metric = c("ciede2000", "din99d", "cie76"), extend = NULL, white_point = c("D65", "D50", "D55", "A", "E") )
n |
The number of colors to generate. |
colorspace |
A color space to generate colors from. Can be any of the following:
|
cvd |
Color vision deficiency adaptation. This must be a named
vector with names |
cvd_severity |
DEPRECATED. Use a named |
bg |
Background color to consider (but not include) when
generating the palette. This is useful to avoid colors that are too
close to the background/canvas color. If |
metric |
The color metric to use for the color distance matrix. |
extend |
A palette of colors to use as a fixed set of initial
colors in the palette, which can be either a matrix or data frame
of RGB values (with values between 0 and 1) or a character vector
of hex colors (or any other format that's acceptable in
|
white_point |
The white point to use for color space conversions. Can be one of "D65" (default, daylight at 6500K), "D50" (daylight at 5000K), "D55" (daylight at 5500K), "A" (incandescent tungsten at 2856K), or "E" (equal energy). |
The main idea is to compute a distance matrix from all the input colors, and
then try to select the most distinct colors based on the color differences
between them. It does this iteratively by first selecting the first n
colors from the input colors, then iterates over the palette, putting colors
back into the total set and replaces it with a new color until it has gone
through the whole range without changing any of the colors.
Optionally, qualpal can adapt palettes to cater to color vision
deficiency (CVD). This is accomplished by taking the colors
provided by the user and transforming them to colors that someone with CVD
would see, that is, simulating CVD qualpal then chooses colors from
these new colors.
A list of class qualpal with the following
components.
HSL |
A matrix of the colors in the HSL color space. |
RGB |
A matrix of the colors in the sRGB color space. |
hex |
A character vector of the colors in hex notation. |
de_DIN99d |
A distance matrix of color differences according to the metric used. The name is misleading, bu kept for backwards compatibility. |
hex |
A character vector of the colors in hex notation. |
min_de_DIN99d |
The minimum pairwise DIN99d color difference among all colors in the palette. |
plot.qualpal(), pairs.qualpal(), list_palettes()
# Generate 3 distinct colors from the default color space qualpal(3) # Provide a custom color space qualpal(n = 3, list(h = c(35, 360), s = c(0.5, 0.7), l = c(0, 0.45))) qualpal(3, "ColorBrewer:Set2") # Adapt palette to deuteranopia qualpal(5, "ColorBrewer:Dark2", cvd = c(deutan = 1)) # Adapt palette to protanomaly with severity 0.4 qualpal(8, cvd = c(protan = 0.4)) # Generate and extend a palette with 3 colors, using the DIN99d # metric pal <- qualpal(3) qualpal(5, extend = pal$hex, metric = "din99d") # Use a different white point (D50, common in printing) qualpal(5, white_point = "D50") ## Not run: # The range of hue cannot exceed 360 qualpal(3, list(h = c(-20, 360), s = c(0.5, 0.7), l = c(0, 0.45))) ## End(Not run)# Generate 3 distinct colors from the default color space qualpal(3) # Provide a custom color space qualpal(n = 3, list(h = c(35, 360), s = c(0.5, 0.7), l = c(0, 0.45))) qualpal(3, "ColorBrewer:Set2") # Adapt palette to deuteranopia qualpal(5, "ColorBrewer:Dark2", cvd = c(deutan = 1)) # Adapt palette to protanomaly with severity 0.4 qualpal(8, cvd = c(protan = 0.4)) # Generate and extend a palette with 3 colors, using the DIN99d # metric pal <- qualpal(3) qualpal(5, extend = pal$hex, metric = "din99d") # Use a different white point (D50, common in printing) qualpal(5, white_point = "D50") ## Not run: # The range of hue cannot exceed 360 qualpal(3, list(h = c(-20, 360), s = c(0.5, 0.7), l = c(0, 0.45))) ## End(Not run)